@@ -323,11 +323,11 @@ def InlineTableFind(codeIn):
                 l=s.split(',')
                 l=[l[0],l[1],l[2],l[3]]
                 if l[1:]==entry:
-                    file=os.path.join(tmpDir,l[0]+'.pyx')
-                    if os.path.exists(file):
-                        fid2=open(file,'r')
+                    filename=os.path.join(tmpDir,l[0]+'.pyx')
+                    if os.path.exists(filename):
+                        fid2=open(filename,'r')
                         if code==fid2.read():
-                            out = file
+                            out = filename
                         fid2.close()
                     break
         fid.close()
@@ -335,7 +335,7 @@ def InlineTableFind(codeIn):
     else:
         return None
 
-# Currently unused...
+# Currently unused... also, needs hashlib
 def InlineTableAddEntry(codeIn):
     val=InlineTableFind(codeIn)
     if val==None:
@@ -392,13 +392,13 @@ CythonPrint('HelloWorld!')
     # Also means memory gets majorly eaten up!
     # Can't have everything!
     moduleName='Cython'+str(random.randint(0,1e18))
-    file=os.path.join(tmpPath,moduleName+'.pyx')
+    filename=os.path.join(tmpPath,moduleName+'.pyx')
     
-    fid=open(file,'w')
+    fid=open(filename,'w')
     fid.write(code)
     fid.close()
     
-    Cpyx(file,useDistutils=useDistutils,useCython=useCython,gccOptions=gccOptions,printCmds=printCmds)
+    Cpyx(filename,useDistutils=useDistutils,useCython=useCython,gccOptions=gccOptions,printCmds=printCmds)
     
     #cmd="""import """+moduleName+""" as LoadPyrexInline"""
     cmd="""from """+moduleName+""" import *"""
